@@ -93,7 +93,7 @@ public:
     Q_INVOKABLE void setWhichJobs(WhichJobs whichjobs);
     KCupsRequest *modifyJob(int row, JobAction action, const QString &newDestName = QString(), const QModelIndex &parent = QModelIndex());
 
-private slots:
+private Q_SLOTS:
     void getJobs();
     void getJobFinished(KCupsRequest *request);
 
@@ -120,12 +120,16 @@ private slots:
                          const QString &jobName,
                          uint jobImpressionsCompleted);
 
+Q_SIGNALS:
+    void error(int lastError, const QString &errorTitle, const QString &errorMsg);
+
 private:
     int jobRow(int jobId);
     void insertJob(int pos, const KCupsJob &job);
     void updateJob(int pos, const KCupsJob &job);
     QString jobStatus(ipp_jstate_e job_state);
     void clear();
+    KCupsRequest *setupRequest(std::function<void()> finished = []() { });
 
     KCupsRequest *m_jobRequest = nullptr;
     QString m_destName;
